searchNodes=[{"doc":"Elixir wrapper for the Bcrypt password hashing function.Most applications will just need to use the add_hash/2 and check_pass/3 convenience functions in this module.For a lower-level API, see Bcrypt.Base.ConfigurationThe following parameter can be set in the config file::log_rounds - the computational cost as number of log roundsthe default is 12 (2^12 rounds)If you are hashing passwords in your tests, it can be useful to add the following to the config/test.exs file:# Note: Do not use this value in production config :bcrypt_elixir, log_rounds: 4BcryptBcrypt is a key derivation function for passwords designed by Niels Provos and David Mazières. Bcrypt is an adaptive function, which means that it can be configured to remain slow and resistant to brute-force attacks even as computational power increases.Bcrypt versionsThis bcrypt implementation is based on the latest OpenBSD version, which fixed a small issue that affected some passwords longer than 72 characters. By default, it produces hashes with the prefix $2b$, and it can check hashes with either the $2b$ prefix or the older $2a$ prefix. It is also possible to generate hashes with the $2a$ prefix by running the following command:Bcrypt.Base.hash_password(&quot;hard to guess&quot;, Bcrypt.gen_salt(12, true))This option should only be used if you need to generate hashes that are then checked by older libraries.The $2y$ prefix is not supported. For advice on how to use hashes with the $2y$ prefix, see this issue. Hash the password with a salt which is randomly generated.","ref":"Bcrypt.html","title":"Bcrypt","type":"module"},{"doc":"Hashes a password, using hash_pwd_salt/2, and returns the password hash in a map.This is a convenience function that is especially useful when used with Ecto changesets.OptionsIn addition to the :hash_key option show below, this function also takes options that are then passed on to the hash_pwd_salt/2 function in this module.See the documentation for hash_pwd_salt/2 for further details.:hash_key - the password hash identifierthe default is :password_hashExample with EctoThe put_pass_hash function below is an example of how you can use add_hash to add the password hash to the Ecto changeset.defp put_pass_hash(%Ecto.Changeset{valid?: true, changes: %{password: password}} = changeset) do change(changeset, add_hash(password)) end defp put_pass_hash(changeset), do: changesetThis function will return a changeset with %{password_hash: password_hash} added to the changes map.","ref":"Bcrypt.html#add_hash/2","title":"Bcrypt.add_hash/2","type":"function"},{"doc":"Checks the password, using verify_pass/2, by comparing the hash with the password hash found in a user struct, or map.This is a convenience function that takes a user struct, or map, as input and seemlessly handles the cases where no user is found.Options:hash_key - the password hash identifierthis does not need to be set if the key is :password_hash or :encrypted_password:hide_user - run the no_user_verify/1 function if no user is foundthe default is trueExampleThe following is an example of using this function to verify a user's password:def verify_user(%{&quot;password&quot; =&gt; password} = params) do params |&gt; Accounts.get_by() |&gt; check_pass(password) endThe Accounts.get_by function in this example takes the user parameters (for example, email and password) as input and returns a user struct or nil.","ref":"Bcrypt.html#check_pass/3","title":"Bcrypt.check_pass/3","type":"function"},{"doc":"Generate a salt for use with the Bcrypt.Base.hash_password function.The :log_rounds parameter determines the computational complexity of the generation of the password hash. Its default is 12, the minimum is 4, and the maximum is 31.The :legacy option is for generating salts with the old $2a$ prefix. Only use this option if you need to generate hashes that are then checked by older libraries.","ref":"Bcrypt.html#gen_salt/2","title":"Bcrypt.gen_salt/2","type":"function"},{"doc":"Hashes a password with a randomly generated salt.Option:log_rounds - the computational cost as number of log roundsthe default is 12 (2^12 rounds)this can be used to override the value set in the configExamplesThe following examples show how to hash a password with a randomly-generated salt and then verify a password:iex&gt; hash = Bcrypt.hash_pwd_salt(&quot;password&quot;) ...&gt; Bcrypt.verify_pass(&quot;password&quot;, hash) true iex&gt; hash = Bcrypt.hash_pwd_salt(&quot;password&quot;) ...&gt; Bcrypt.verify_pass(&quot;incorrect&quot;, hash) false","ref":"Bcrypt.html#hash_pwd_salt/2","title":"Bcrypt.hash_pwd_salt/2","type":"function"},{"doc":"Runs the password hash function, but always returns false.This function is intended to make it more difficult for any potential attacker to find valid usernames by using timing attacks. This function is only useful if it is used as part of a policy of hiding usernames.OptionsThis function should be called with the same options as those used by hash_pwd_salt/2.Hiding usernamesIn addition to keeping passwords secret, hiding the precise username can help make online attacks more difficult. An attacker would then have to guess a username / password combination, rather than just a password, to gain access.This does not mean that the username should be kept completely secret. Adding a short numerical suffix to a user's name, for example, would be sufficient to increase the attacker's work considerably.If you are implementing a policy of hiding usernames, it is important to make sure that the username is not revealed by any other part of your application.","ref":"Bcrypt.html#no_user_verify/1","title":"Bcrypt.no_user_verify/1","type":"function"},{"doc":"Verifies a password by hashing the password and comparing the hashed value with a stored hash.See the documentation for hash_pwd_salt/2 for examples of using this function.","ref":"Bcrypt.html#verify_pass/2","title":"Bcrypt.verify_pass/2","type":"function"},{"doc":"Base module for the Bcrypt password hashing library.","ref":"Bcrypt.Base.html","title":"Bcrypt.Base","type":"module"},{"doc":"Verify the password by comparing it with the stored hash.","ref":"Bcrypt.Base.html#checkpass_nif/2","title":"Bcrypt.Base.checkpass_nif/2","type":"function"},{"doc":"Generate a salt for use with Bcrypt.","ref":"Bcrypt.Base.html#gensalt_nif/3","title":"Bcrypt.Base.gensalt_nif/3","type":"function"},{"doc":"Hash the password and salt with the Bcrypt hashing algorithm.","ref":"Bcrypt.Base.html#hash_nif/2","title":"Bcrypt.Base.hash_nif/2","type":"function"},{"doc":"Hash a password using Bcrypt.","ref":"Bcrypt.Base.html#hash_password/2","title":"Bcrypt.Base.hash_password/2","type":"function"},{"doc":"","ref":"Bcrypt.Base.html#init/0","title":"Bcrypt.Base.init/0","type":"function"},{"doc":"Module to provide statistics for the Bcrypt password hashing function.The report/1 function in this module can be used to help you configure Bcrypt.ConfigurationThere is one configuration option for Bcrypt - :log_rounds. Increasing this value will increase the complexity, and time taken, of the Bcrypt function.Increasing the time that a password hash function takes makes it more difficult for an attacker to find the correct password. However, the amount of time a valid user has to wait also needs to be taken into consideration when setting the number of log rounds.The correct number of log rounds depends on circumstances specific to your use case, such as what level of security you want, how often the user has to log in, and the hardware you are using. However, for password hashing, we do not recommend setting the number of log rounds to anything less than 12.","ref":"Bcrypt.Stats.html","title":"Bcrypt.Stats","type":"module"},{"doc":"Hash a password with Bcrypt and print out a report.This function hashes a password, and salt, with Bcrypt.Base.hash_password/2 and prints out statistics which can help you choose how many to configure Bcrypt.OptionsThere are three options::log_rounds - the number of log roundsthe default is 12:password - the password usedthe default is &quot;password&quot;:salt - the salt usedthe default is the output of Bcrypt.gen_salt","ref":"Bcrypt.Stats.html#report/1","title":"Bcrypt.Stats.report/1","type":"function"},{"doc":"Changelog","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"ChangesUpdated documentation","ref":"changelog.html#v2-3-1-2022-01-19","title":"Changelog - v2.3.1 (2022-01-19)","type":"extras"},{"doc":"EnhancementsUpdated Makefile to be more robust, especially for Nerves users","ref":"changelog.html#v2-3-0-2021-01-07","title":"Changelog - v2.3.0 (2021-01-07)","type":"extras"},{"doc":"ChangesUsing Comeonin v5.3, which changes add_hash so that it does NOT set the password to nil","ref":"changelog.html#v2-2-0-2020-03-01","title":"Changelog - v2.2.0 (2020-03-01)","type":"extras"},{"doc":"EnhancementsUpdated documentation - in line with updates to Comeonin v5.2","ref":"changelog.html#v2-1-0-2020-01-20","title":"Changelog - v2.1.0 (2020-01-20)","type":"extras"},{"doc":"EnhancementsUpdated to use the Comeonin and Comeonin.PasswordHash behaviours (Comeonin v5.0)","ref":"changelog.html#v2-0-0-2019-02-12","title":"Changelog - v2.0.0 (2019-02-12)","type":"extras"},{"doc":"EnhancementsUpdated C NIF code to use dirty schedulers","ref":"changelog.html#v1-0-0-2019-01-17","title":"Changelog - v1.0.0 (2019-01-17)","type":"extras"},{"doc":"ChangesCreated separate Bcrypt library","ref":"changelog.html#v0-12-0-2017-08-06","title":"Changelog - v0.12.0 (2017-08-06)","type":"extras"},{"doc":"Bcrypt Bcrypt password hashing library for Elixir.Bcrypt is a well-tested password-based key derivation function that can be configured to remain slow and resistant to brute-force attacks even as computational power increases.","ref":"readme.html","title":"Bcrypt","type":"extras"},{"doc":"This version is based on the OpenBSD version of Bcrypt and supports the $2b$ and $2a$ prefixes. For advice on how to use hashes with the $2y$ prefix, see this issue.","ref":"readme.html#compatibility-with-other-bcrypt-libraries","title":"Bcrypt - Compatibility with other Bcrypt libraries","type":"extras"},{"doc":"Add :bcrypt_elixir to the deps section of your mix.exs file:If you are using Erlang &gt;20:def deps do [ {:bcrypt_elixir, &quot;~&gt; 2.0&quot;} ] endIf you are using Erlang 19 or below:def deps do [ {:bcrypt_elixir, &quot;~&gt; 0.12&quot;} ] end Make sure you have a C compiler installed. See the Comeonin wiki for details. Optional: during tests (and tests only), you may want to reduce the number of rounds so it does not slow down your test suite. If you have a config/test.exs, you should add:config :bcrypt_elixir, :log_rounds, 4","ref":"readme.html#installation","title":"Bcrypt - Installation","type":"extras"},{"doc":"See the Comeonin wiki for more information on the following topics:AlgorithmsRequirementsDeploymentIncluding information about using DockerReferences","ref":"readme.html#comeonin-wiki","title":"Bcrypt - Comeonin wiki","type":"extras"},{"doc":"There are many ways you can contribute to the development of this library, including:Reporting issuesImproving documentationSharing your experiences with othersDocumentationhttp://hexdocs.pm/bcrypt_elixirLicenseBSD. For full details, please read the LICENSE file.","ref":"readme.html#contributing","title":"Bcrypt - Contributing","type":"extras"}]